lck.django.badges.models
========================

.. automodule:: lck.django.badges.models


Functions
---------

.. autofunction:: update_group 

.. autofunction:: update_type 


Classes
-------

.. autoclass:: BadgeGroup
   :show-inheritance:
   :members:
   

.. autoclass:: BadgeType
   :show-inheritance:
   :members:
   

.. autoclass:: Badge
   :show-inheritance:
   :members:
   

.. autoclass:: BadgeIcon
   :show-inheritance:
   :members:
